SliderAppBarConfig class

Constructors

SliderAppBarConfig({Widget title = const Text('AppBar'), Color? backgroundColor, EdgeInsets? padding, Widget? trailing, Color drawerIconColor = const Color(0xff2c2b2b), double drawerIconSize = 27, bool isCupertino = false, Color? splashColor, ImageProvider<Object>? drawerOpenIcon, ImageProvider<Object>? drawerCloseIcon, AnimationController? animationController})
const

Properties

animationController AnimationController?
final
backgroundColor Color?
Color you can change appbar color by this parameter backgroundColor
final
drawerCloseIcon ImageProvider<Object>?
final
drawerIconColor Color
Color you can change drawer icon by this parameter drawerIconColor
final
drawerIconSize double
double you can change drawer icon size by this parameter drawerIconSize
final
drawerOpenIcon ImageProvider<Object>?
🆕 Custom icons for open and close drawer states If both are provided, they override the default AnimatedIcon
final
hashCode int
The hash code for this object.
no setterinherited
isCupertino bool
bool true means use cupertino icon of drawer for animation isCupertino false means use material icon of drawer animation Default value : false
final
padding EdgeInsets?
EdgeInsets you can change appBarPadding by this parameter padding
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
splashColor Color?
The primary color of the button when the button is in the down (pressed) state.
final
title Widget
Widget you can set appbar title by this parameter title
final
trailing Widget?
Widget you can set trailing of appbar by this parameter trailing
final

Methods

copyWith({double? height, Widget? title, bool? isTitleCenter, Color? backgroundColor, EdgeInsets? padding, Widget? trailing, Color? drawerIconColor, double? drawerIconSize, bool? isCupertino, Color? splashColor, ImageProvider<Object>? drawerOpenIcon, ImageProvider<Object>? drawerCloseIcon, AnimationController? animationController}) SliderAppBarConfig
Creates a copy of this configuration with the given fields replaced
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited