SliderDrawer class
SliderDrawer which have two child and slider parameter
For Example :
SliderDrawer( key: _sliderDrawerKey, appBar: SliderAppBar( config: SliderAppBarConfig( title: Text( title, textAlign: TextAlign.center, style: const TextStyle( fontSize: 22, fontWeight: FontWeight.w700, ), )), ), sliderOpenSize: 179, slider: SliderMenu(), child: const AuthorList(), )
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- SliderDrawer
Constructors
- SliderDrawer({Key? key, required Widget slider, required Widget child, bool isDraggable = true, int animationDuration = 400, double sliderOpenSize = 265, double sliderCloseSize = 0, SlideDirection slideDirection = SlideDirection.leftToRight, SliderBoxShadow? sliderBoxShadow, Widget? appBar, SliderAppBarConfig? appBarConfig, Color? backgroundColor})
-
const
Properties
- animationDuration → int
-
int animation duration for the drawer's open/close action in milliseconds.
parameter
final
- appBar → Widget?
-
appBar if you set
nullthen it will not display app barfinal - appBarConfig → SliderAppBarConfig?
-
final
- backgroundColor → Color?
-
The theme's ThemeData.scaffoldBackgroundColor by default.
final
- child → Widget
-
Widget main screen widget
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDraggable → bool
-
bool if you set
falsethen swipe to open feature disable. By Default it's truefinal - key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- slideDirection → SlideDirection
-
slideDirection you can change slide direction by this parameter slideDirection
There are three type of SlideDirection
SlideDirection.rightToLeft
SlideDirection.leftToRight
SlideDirection.topToBottom
final
- slider → Widget
-
Widget which display when user open drawer
final
- sliderBoxShadow → SliderBoxShadow?
-
SliderBoxShadow you can enable shadow of child Widget by this parameter
final
- sliderCloseSize → double
-
double The width of the closed drawer. Default is 0.
final
- sliderOpenSize → double
-
The width of the open drawer.
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → SliderDrawerState -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited